@@ -15,12 +15,15 @@ def aNumberOfFactorial(number):
         result = result * item
     return result
 def squareRoot_negativeNumber(number):
-    num = number
-    num_sqrt = cmath.sqrt(num)
-    return '{0} 的平方根为 {1:0.3f}+{2:0.3f}j'.format(num ,num_sqrt.real,num_sqrt.imag)
+    num_sqrt = cmath.sqrt(number)
+    copiseded_numbertimes = '{0} 的平方根为 {1:0.3f}+{2:0.3f}j'.format(number,
+    num_sqrt.real,num_sqrt.imag)
+    return copiseded_numbertimes
+
 def squareRoot_positiveNumber(number):
-    num = number
-    num_sqrt = num ** 0.5
-    return ' %0.3f 的平方根为 %0.3f'%(num ,num_sqrt)
+    num_sqrt = number ** 0.5
+    copiseded_number = ' %0.3f 的平方根为 %0.3f'%(number ,num_sqrt)
+    return copiseded_number
 def squareOfANumber(number):
-    return number * number
+    result = number * number
+    return result
